@@ -47,21 +47,24 @@
  *
  */
 
+
 package com.openexchange.documentconverter;
 
 public enum Feature {
 
     // - Enums -----------------------------------------------------------------
 
+    // Usage as document converter possible
     DOCUMENTCONVERTER(0x00000001),
 
-    // you may pass a source mime type String
-    // parameter to the IManager.hasFeature method,
-    // in order to detect if the SharePoint service
-    // is supported for this kind of source document
-    SHAREPOINT_PDFCONVERSION(0x00000002),
+    // instance uses a remote document converter
+    REMOTE_DOCUMENTCONVERTER(0x00000004),
 
-    REMOTE_DOCUMENTCONVERTER(0x00000004);
+    // usage as image server possible
+    IMAGESERVER(0x00000008),
+
+    // instance uses a remote image server
+    REMOTE_IMAGESERVER(0x00000010);
 
     // - Enum implementation ---------------------------------------------------
 
