@@ -47,6 +47,7 @@
  *
  */
 
+
 package com.openexchange.documentconverter;
 
 import java.io.IOException;
@@ -90,23 +91,21 @@ public interface IJob {
     HashMap<String, Object> getResultProperties();
 
     /**
-     * @return <code>true</code>, if the implemented execute method needs an
-     *  {@link IInstance} interface to work with, <code>false</code> otherwise
+     * @return The type of engine, the current job is assigned to
      */
-    abstract BackendType backendTypeNeeded();
+    abstract EngineType engineTypeNeeded();
 
     /**
      * This method will be called in order to let the job do the real work
      *
-     * @param instance The instance which triggers this job execution
-     * @return true In case the execution succeeeded
-     * @throws com.sun.star.lang.DisposedException
+     * @param jobExecutionData
+     * @return
      * @throws InterruptedException
      * @throws IOException
      * @throws MalformedURLException
      * @throws Exception
      */
-    abstract boolean execute(IInstance instance) throws com.sun.star.lang.DisposedException, InterruptedException, IOException, MalformedURLException, Exception;
+    abstract boolean execute(Object jobExecutionData) throws InterruptedException, IOException, MalformedURLException, Exception;
 
     abstract void kill() throws Exception;
 }
