@@ -61,12 +61,28 @@ public class Properties {
 
     static final public String INFO_PREFIX = "info_";
 
+    static final public String REMOTECACHE_VERSION_PREFIX = "rc1-";
+
+    // -------------------------------------------------------------------------
+
+    static final public int MAX_ERROR_MESSAGE_TOTAL_LENGTH = 2048;
+
+    static final public int MAX_ERROR_MESSAGE_END_LENGTH = 256;
+
+    // -------------------------------------------------------------------------
+
+    static final public int JOB_MAJOR_VERSION = 1;
+
+    static final public int JOB_MINOR_VERSION = 1;
+
     // -------------------------------------------------------------------------
 
     static final public String CACHE_PROPERTIES_FILENAME = "properties"; // String
 
     static final public String CACHE_RESULT_FILENAME = "result"; // String
 
+    static final public String CACHE_NO_CACHEHASH = "0";
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_CACHE_PERSIST_ENTRY_NAME = "EntryName"; // String
@@ -83,9 +99,9 @@ public class Properties {
 
     static final public String PROP_IMANAGER = "IManager"; // IManager
 
-    static final public String PROP_IMAGE_RESOLUTION = "ImageResolution"; // Integer
+    static final public String PROP_PIXEL_X = "PixelX"; // Integer
 
-    static final public String PROP_IMAGE_SCALE_TYPE = "ImageScaleType"; // String
+    static final public String PROP_PIXEL_Y = "PixelY"; // Integer
 
     static final public String PROP_PIXEL_WIDTH = "PixelWidth"; // Integer
 
@@ -117,7 +133,7 @@ public class Properties {
 
     static final public String PROP_READERENGINE_ROOT = "ReaderEngineRoot"; // String
 
-    static final public String PROP_READERENGINE_REMOTEURL = "ReaderEngineRemoteUrl"; // String
+    static final public String PROP_ENGINE_REMOTEURL = "EngineRemoteUrl"; // String
 
     static final public String PROP_REMOTE_METHOD = "Method"; // String
 
@@ -139,6 +155,18 @@ public class Properties {
 
     static final public String PROP_ASYNC = "Async"; // Boolean
 
+    static final public String PROP_IMAGE_FORMAT = "ImageFormat"; // String
+
+    static final public String PROP_IMAGE_TRANSFORMATIONS = "ImageTransformations"; // ImageServerTransformations
+
+    static final public String PROP_IMAGE_TRANSFORMATION_SOURCE = "ImageTransformationSource"; // Object
+
+    static final public String PROP_IMAGE_RESOLUTION = "ImageResolution"; // Integer
+
+    static final public String PROP_IMAGE_SCALE_TYPE = "ImageScaleType"; // String
+
+    static final public String PROP_IMAGE_SHRINK_ONLY = "ImageShrinkOnly"; // String
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
@@ -179,12 +207,24 @@ public class Properties {
 
     static final public String PROP_RESULT_CONVERTER_COOKIE = PROP_CONVERTER_COOKIE; // String
 
+    static final public String PROP_RESULT_IMAGE_DATA = PROP_RESULT_BUFFER; // byte[]
+
+    static final public String PROP_RESULT_IMAGE_FORMAT = PROP_IMAGE_FORMAT; // String
+
+    static final public String PROP_RESULT_IMAGE_WIDTH = PROP_PIXEL_WIDTH; // Integer
+
+    static final public String PROP_RESULT_IMAGE_HEIGHT = PROP_PIXEL_HEIGHT; // Integer
+
+    static final public String PROP_RESULT_ASYNC = PROP_ASYNC; // Boolean
+
     // -------------------------------------------------------------------------
 
     static public final String OX_RESCUEDOCUMENT_EXTENSION_APPENDIX = "_ox";
 
     static public final String OX_DOCUMENTCONVERTER_TEMPDIR_NAME = "oxdc.tmp";
 
+    // -------------------------------------------------------------------------
+
     @SuppressWarnings("unchecked")
     static public <T> T getValue(Map<String, ?> map, String key) {
         return (T) (((null != map) && (!StringUtils.isEmpty(key))) ? map.get(key) : null);
